// Copyright 2021 Dolphin Emulator Project
// SPDX-License-Identifier: GPL-2.0-or-later

#pragma once

namespace ciface::Android
{
void Init();
void Shutdown();

void PopulateDevices();

}  // namespace ciface::Android
